@@ -41,7 +41,7 @@
 #include <tdemessagebox.h>
 #include <kstandarddirs.h>
 #include <tdeversion.h>
-#include <ntqpopupmenu.h>
+#include <tqpopupmenu.h>
 
 #include "kstreamripper.h"
 #include "streampropertiesdlg.h"
@@ -307,7 +307,8 @@ void KStreamRipper::browseButtonClicked()
     TQString openDest = KFileDialog::getExistingDirectory( TQDir::homeDirPath(),
                                                           this,
                                                           "Select Destination..." );
-    m_destEdit->setText( openDest );
+    if ( !openDest.isEmpty() )
+        m_destEdit->setText( openDest );
 }
 
 void KStreamRipper::helpButtonClicked()
